from pathlib import Path
from pydantic_settings import BaseSettings, SettingsConfigDict


class Settings(BaseSettings):
    app_name: str = "Shopping App"
    database_url: str  # Ensure lowercase to match the .env key
    secret_key: str
    debug: bool = True  # Lowercase to match Python conventions

    model_config = SettingsConfigDict(
        env_file=str(Path(__file__).resolve().parent.parent / ".env"),
        env_file_encoding="utf-8",
        case_sensitive=False,  # Allows case-insensitive environment variable keys
    )


# Create a singleton instance to use in the app
settings = Settings()
